// $Id: Application.cpp,v 1.21 2013/02/14 09:02:48 hupereir Exp $

/******************************************************************************
 *
 * Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
 *
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * software; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *
 *******************************************************************************/

#include "Application.h"
#include "BaseIcons.h"
#include "Config.h"
#include "ConfigurationDialog.h"
#include "IconEngine.h"
#include "MainWindow.h"
#include "QtUtil.h"
#include "Util.h"

#include <QApplication>
#include <QLayout>
#include <QLabel>
#include <QMessageBox>

//____________________________________________
void Application::usage( void )
{
  Debug::Throw(0) << "usage : xgrabcolor [options]" << endl;
  SERVER::ApplicationManager::commandLineParser().usage();
  return;
}

//____________________________________________
Application::Application( CommandLineArguments arguments ) :
  BaseApplication( 0, arguments ),
  Counter( "Application" ),
  MAIN_TITLE( "xgrabcolor" ),
  mainWindow_(0)
{ Debug::Throw( "Application::Application.\n" ); }

//____________________________________________
Application::~Application( void )
{}

//____________________________________________
bool Application::realizeWidget( void )
{
  Debug::Throw( "Application::realizeWidget.\n" );

  if( !BaseApplication::realizeWidget() ) return false;

  // rename about action
  aboutAction().setText( "About Xgrabcolor" );
  configurationAction().setText( "Configure Xgrabcolor..." );

  // top widget
  mainWindow_ = new MainWindow();
  Debug::Throw( "Application::realizeWidget - top widget set.\n" );

  // change window title
  mainWindow().setWindowTitle( MAIN_TITLE );
  Debug::Throw( "Application::realizeWidget - window title set.\n" );

  // configuration
  emit configurationChanged();

  // top widget
  mainWindow().centerOnDesktop();
  mainWindow().show();

  Debug::Throw( "Application::realizeWidget - done.\n" );

  return true;

}

//_______________________________________________
void Application::_configuration( void )
{

  Debug::Throw( "Application::_configuration.\n" );
  emit saveConfiguration();
  ConfigurationDialog dialog;
  connect( &dialog, SIGNAL( configurationChanged() ), SIGNAL( configurationChanged() ) );
  dialog.centerOnWidget( qApp->activeWindow() );
  dialog.exec();

}

//________________________________________________
bool Application::_processCommand( SERVER::ServerCommand command )
{

  Debug::Throw( "Application::_processCommand.\n" );
  if( BaseApplication::_processCommand( command ) ) return true;
  if( command.command() == SERVER::ServerCommand::RAISE )
  {
    mainWindow().uniconify();
    return true;
  } else return false;

}
