#ifndef Application_h
#define Application_h

// $Id: Application.h,v 1.12 2013/02/14 09:02:48 hupereir Exp $

/******************************************************************************
 *
 * Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
 *
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * software; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *
 *******************************************************************************/

#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "Config.h"
#include "Counter.h"

#include <QAction>
#include <QCursor>

class MainWindow;

//! Main Window singleton object
class Application: public BaseApplication, public Counter
{

  //! Qt meta object declaration
  Q_OBJECT

  public:

  //! usage
  static void usage( void );

  //! constructor
  Application( CommandLineArguments );

  //! destructor
  virtual ~Application( void );

  //! default window title
  const QString MAIN_TITLE;

  //! create all widgets
  virtual bool realizeWidget( void );

  //! retrieves top layout
  virtual MainWindow & mainWindow( void ) const
  { return *mainWindow_; }

  protected slots:

  //! process request from application manager
  virtual bool _processCommand( SERVER::ServerCommand );

  //! about
  virtual void _about( void )
  { BaseApplication::_about( MAIN_TITLE, VERSION, BUILD_TIMESTAMP ); }

  //! configuration
  virtual void _configuration( void );

  private:

  //! pointer to top widget
  MainWindow *mainWindow_;

};

#endif
