// $Id: ColorList.cpp,v 1.14 2013/02/22 12:05:49 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/


#include "ColorList.h"

#include "ContextMenu.h"
#include "GridLayout.h"
#include "Debug.h"
#include "BaseIcons.h"
#include "IconEngine.h"
#include "QtUtil.h"
#include "QuestionDialog.h"
#include "Str.h"
#include "Util.h"

//____________________________________________________________
ColorList::ColorList( QWidget* parent ):
    QGroupBox( "Saved Colors", parent )
{

    Debug::Throw( "ColorList::ColorList.\n" );

    _installActions();

    QVBoxLayout* layout = new QVBoxLayout( this );
    layout->setMargin(5);
    layout->setSpacing(5);
    setLayout( layout );

    layout->addWidget( list_ = new TreeView( this ) );
    list_->setModel( &model_ );
    list_->setSelectionMode( QAbstractItemView::ContiguousSelection );
    ( new ContextMenu( list_ ) )->addAction( &removeAction() );
    connect( list_->selectionModel(), SIGNAL( selectionChanged(const QItemSelection &, const QItemSelection &) ), SLOT( _updateActions() ) );
    _updateActions();

}

//____________________________________________________________
void ColorList::add( const QColor& color, const bool& select )
{

    Debug::Throw( "ColorList::add.\n" );
    model().add( color );

    // retrieve index
    if( select )
    {
        QModelIndex selected_index( model().index( color ) );
        list_->selectionModel()->select( selected_index,  QItemSelectionModel::Clear|QItemSelectionModel::Select|QItemSelectionModel::Rows );
    }

}

//_____________________________________________________________
void ColorList::_remove( void )
{
    Debug::Throw( "ColorList::_remove\n" );

    // retrieve selected indexes in list
    QModelIndexList selected_indexes( list_->selectionModel()->selectedRows() );
    if( selected_indexes.empty() || !QuestionDialog( this, "Remove selected colors from list ?" ).exec() ) return;

    ColorModel::List colors( model().get( selected_indexes ) );
    for( ColorModel::List::iterator iter = colors.begin(); iter != colors.end(); ++iter )
    { model().remove( *iter ); }

    _updateActions();

}

//_________________________________________________________________________
void ColorList::_updateActions( void )
{
    Debug::Throw( "ColorList::_updateActions.\n" );
    bool has_selection( !list_->selectionModel()->selectedRows().empty() );
    removeAction_->setEnabled( has_selection );
}

//_________________________________________________________________________
void ColorList::_installActions( void )
{
    Debug::Throw( "ColorList::_installActions.\n" );

    // actions
    addAction( removeAction_ = new QAction( IconEngine::get( ICONS::REMOVE ), "Remove", this ) );
    removeAction_->setToolTip( "Remove selected colors" );
    removeAction_->setShortcut( QKeySequence::Delete );
    connect( removeAction_, SIGNAL( triggered() ), SLOT( _remove() ) );

}
