// $Id: ColorModel.cpp,v 1.21 2013/03/08 09:30:04 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "ColorModel.h"

#include "CustomPixmap.h"
#include "Debug.h"
#include "IconSize.h"

#include <QPainter>

//_______________________________________________
ColorModel::IconCache& ColorModel::_icons( void )
{
    static IconCache singleton;
    return singleton;
}

//_______________________________________________
const QString ColorModel::columnTitles_[ ColorModel::nColumns ] =
{ "Color Name" };

//__________________________________________________________________
QVariant ColorModel::data( const QModelIndex& index, int role ) const
{

    // check index, role and column
    if( !index.isValid() ) return QVariant();

    // retrieve associated color
    const BASE::Color& color( get( index ) );
    if( role == Qt::DisplayRole && index.column() == COLOR ) return color.name();
    else if( role == Qt::DecorationRole && index.column() == COLOR ) return _icon( color );
    else return QVariant();

}

//__________________________________________________________________
QVariant ColorModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}

//____________________________________________________________
void ColorModel::_sort( int column, Qt::SortOrder order )
{
    Debug::Throw() << "ColorModel::sort - column: " << column << " order: " << order << endl;
    std::sort( _get().begin(), _get().end(), SortFTor( (ColumnType) column, order ) );
}

//________________________________________________________
bool ColorModel::SortFTor::operator () ( BASE::Color first, BASE::Color second ) const
{

    if( order_ == Qt::DescendingOrder ) std::swap( first, second );
    return first < second;
}

//______________________________________________________
QIcon ColorModel::_icon( const BASE::Color& color )
{

    IconCache::iterator iter( _icons().find( color ) );
    if( iter != _icons().end() ) return iter.value();
    else {

        QPixmap pixmap( CustomPixmap().empty( IconSize( IconSize::Large ) ) );
        QPainter painter( &pixmap );
        painter.setBrush( color );
        painter.setRenderHints(QPainter::Antialiasing );

        QRect rect( pixmap.rect() );
        rect.adjust( 2, 2, -2, -2 );

        painter.setPen( Qt::NoPen );
        if( color.alpha() == 255 )
        {
            // full circle for opaque colors
            painter.setBrush( color );
            painter.drawEllipse( rect );

        } else {

            // right side of the circle is transparent
            painter.setBrush( color );
            painter.drawChord( rect, -90*16, 180*16 );

            // left side of circle is opaque
            painter.setBrush( QColor( color.rgb() ) );
            painter.drawChord( rect, 90*16, 180*16 );

        }

        // surrounding rect
        painter.setPen( QPalette().color( QPalette::Text ) );
        painter.setBrush( Qt::NoBrush );
        painter.drawEllipse( rect );

        QIcon icon( pixmap );
        _icons()[color] = icon;
        return icon;

    }

}
