#ifndef ColorModel_h
#define ColorModel_h

// $Id: ColorModel.h,v 1.12 2013/03/08 09:30:05 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Color.h"
#include "Counter.h"
#include "ListModel.h"

#include <QMap>
#include <QIcon>

//! Color model. Stores Color information for display in lists
class ColorModel : public ListModel<BASE::Color>, public Counter
{

    public:

    //! constructor
    ColorModel( QObject *parent = 0 ):
        ListModel<BASE::Color>( parent ),
        Counter( "ColorModel" )
    {}

    //! destructor
    virtual ~ColorModel( void )
    {}

    //! number of columns
    enum { nColumns = 1 };

    //! column type enumeration
    enum ColumnType {
        COLOR
    };

    //!@name methods reimplemented from base class
    //@{

    // return job for a given index
    virtual QVariant data( const QModelIndex&, int ) const;

    //! header data
    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;

    //! number of columns for a given index
    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
    { return nColumns; }

    //@}

    protected:

    //! sort
    virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder );

    private slots:

    //! update configuration
    void _updateConfiguration( void );

    private:

    //! used to sort IconCaches
    class SortFTor: public ItemModel::SortFTor
    {

        public:

        //! constructor
        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
            ItemModel::SortFTor( type, order )
            {}

        //! prediction
        bool operator() ( BASE::Color, BASE::Color ) const;

    };

    //! icon cache
    typedef QMap<BASE::Color, QIcon> IconCache;

    //! icon cache
    static IconCache& _icons( void );

    //! icon matching color
    static QIcon _icon( const BASE::Color& );

    //! list column names
    static const QString columnTitles_[nColumns];

};

#endif
