// $Id: Menu.cpp,v 1.13 2013/02/14 09:02:48 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file Menu.cc
\brief main menu
\author Hugo Pereira
\version $Revision: 1.13 $
\date $Date: 2013/02/14 09:02:48 $
*/

#include "Application.h"
#include "Debug.h"
#include "DebugMenu.h"
#include "MainWindow.h"
#include "Menu.h"
#include "Singleton.h"
#include "XmlOptions.h"

#include <QMenu>

//__________________________________________________
Menu::Menu( QWidget* parent ):
QMenuBar( parent ),
Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu" );

    // generic menu
    QMenu *menu;

    // application and top widget
    Application& application( *Singleton::get().application<Application>() );
    MainWindow& mainwindow( *static_cast<MainWindow*>(window()) );

    // file menu
    menu = addMenu( "File" );
    menu->addAction( &application.closeAction() );

    // Settings menu
    menu = addMenu( "Settings" );
    menu->addAction( &mainwindow.toggleListAction() );
    menu->addSeparator();
    menu->addAction( &application.configurationAction() );

    // create help menu
    menu = addMenu( "Help" );
    menu->addAction( &application.aboutQtAction() );
    menu->addAction( &application.aboutAction() );

    // debug menu
    #ifdef DEBUG
    menu->addSeparator();
    DebugMenu *debug_menu( new DebugMenu( this ) );
    debug_menu->setTitle( "Debug" );
    menu->addMenu( debug_menu );
    #endif

}
